
*********** ASSEMBLE THE MASTER DATA

* Start with office-quarter data productivity and output
use "$dta/budget_prod_eq_2007_2016.dta", clear
keep  cod_regione regione cod_sede_budg sede anno produz_eq_sede prod_sede* naz quart year_quarter
duplicates drop

* Merge in office-quarter data on the human resource budget (FTE, absences, overtime, etc.)
merge m:1 cod_sede_budg year_quarter using "$tempfiles/budg_abc_prod_lorda_sede_2007_2016.dta"
assert _merge==3
drop _merge

gen mese=3 if quart==1 
replace mese=6 if quart==2
replace mese=9 if quart==3
replace mese=12 if quart==4


replace sede="BARLETTA-ANDRIA-TRANI - dir" if sede=="ANDRIA - dir"
replace sede="FC POZZUOLI - fil" if sede=="FC POZZUOLI"
replace sede="FC ROMA TUSCOLANO - fil" if sede=="FC ROMA TUSCOLANO"

* Merge in office-quarter data on the quality index (2005-2016)
merge 1:1 sede anno mese using "$dta/crusc_dir_v2_trimesters_adjusted.dta"
drop if _merge==2 
drop _merge

* Merge in office-quarter data on the quality index (2017)
merge 1:1 sede anno mese using "$dta/crusc_dir_v2_trimesters_adjusted_2017.dta", keepusing(qual_pp) update
drop if _merge==2 
drop _merge

rename cod_sede_budg cod_sede_giu
rename quart quarter

replace cod_sede_giu="090100" if sede=="BARLETTA-ANDRIA-TRANI - dir" & cod_sede_giu==""
replace cod_sede_giu="510100" if sede=="CASTELLAMMARE DI STABIA - fil" & cod_sede_giu==""
replace cod_sede_giu="510500" if sede=="FC CAMALDOLI VOMERO - fil" & cod_sede_giu==""
replace cod_sede_giu="516000" if sede=="FC NOLANA - fil" & cod_sede_giu==""
replace cod_sede_giu="701400" if sede=="FC NORD-OVEST FLAMINIO - fil" & cod_sede_giu==""
replace cod_sede_giu="510600" if sede=="FC POZZUOLI - fil" & cod_sede_giu==""
replace cod_sede_giu="700400" if sede=="FC ROMA MONTESACRO - fil" & cod_sede_giu==""
replace cod_sede_giu="701000" if sede=="FC ROMA TUSCOLANO - fil" & cod_sede_giu==""
replace cod_sede_giu="517000" if sede=="FC STABIESE - fil" & cod_sede_giu==""
replace cod_sede_giu="700900" if sede=="FC SUD-EST CASILINO - fil" & cod_sede_giu==""
replace cod_sede_giu="700100" if sede=="FC SUD-OVEST EUR - fil" & cod_sede_giu==""
replace cod_sede_giu="060001" if sede=="FERMO - dir" & cod_sede_giu==""
replace cod_sede_giu="510000" if sede=="NAPOLI - fil" & cod_sede_giu==""
replace cod_sede_giu="510000" if sede=="NAPOLI-AREA METROPOLITANA - dir" & cod_sede_giu==""
replace cod_sede_giu="516000" if sede=="NAPOLI-AREA NOLANA FDC - dir" & cod_sede_giu==""
replace cod_sede_giu="510100" if sede=="NAPOLI-AREA STABIESE FDC - dir" & cod_sede_giu==""
replace cod_sede_giu="516000" if sede=="NOLA - fil" & cod_sede_giu==""
replace cod_sede_giu="700900" if sede=="RM CASILINO FDC - dir" & cod_sede_giu==""
replace cod_sede_giu="700100" if sede=="RM EUR FDC - dir" & cod_sede_giu==""
replace cod_sede_giu="701400" if sede=="RM FLAMINIO FDC - dir" & cod_sede_giu==""
replace cod_sede_giu="700000" if sede=="ROMA - fil" & cod_sede_giu==""
replace cod_sede_giu="700000" if sede=="ROMA AREA METROPOLITANA - dir" & cod_sede_giu==""
replace cod_sede_giu="510301" if sede=="AFRAGOLA"
replace cod_sede_giu="510010" if sede=="TORRE DEL GRECO" 
replace cod_sede_giu="048001" if sede=="VERRES" 
replace cod_sede_giu="250004" if sede=="SAN GIOVANNI IN FIORE" 

* Merge in manager data for main offices and local branches
merge m:1 cod_sede_giu anno quarter using "$dta/managers_characteristics_2005_2017_v3.dta"
drop if _merge==2
drop _merge

replace exo_strict=0 if exo_strict==.
replace exo_final=0 if exo_final==.

drop naz
gen naz=1 if sede=="NAZIONALE"
gen cl=1 if sede=="CLUSTER A" | sede=="CLUSTER B" | sede=="CLUSTER C" | sede=="CLUSTER D" 
gen reg=1 if sede=="PIEMONTE" | sede=="VALLE D'AOSTA" | sede=="LIGURIA" | sede=="LOMBARDIA" | ///
	sede=="VENETO" | sede=="TRENTINO ALTO ADIGE" | sede=="FRIULI VENEZIA GIULIA" | sede=="EMILIA ROMAGNA" | sede=="ABRUZZO" | ///
	sede=="MOLISE" | sede=="MARCHE" | sede=="TOSCANA" | sede=="LAZIO" | sede=="PUGLIA" | ///
	sede=="CAMPANIA" | sede=="BASILICATA" | sede=="CALABRIA" | sede=="SICILIA" | sede=="SARDEGNA" | ///
	sede=="UMBRIA" 
gen a=substr(sede, -3,3)	
gen fil=1 if a=="fil"
gen dir=1 if a=="dir"
gen agen=1 if naz!=1 & cl!=1 & reg!=1 & fil!=1 & dir!=1

* Drop data before 2011 (the data before 2011 is very sparse and it is aggregate by province)
drop if anno<2011
* Keep only production sites (i.e., main offices and local branches)
drop if agen!=1

* Merge in office-quarter data on hires, fires, retirement, separations, and moves
merge 1:1 cod_sede_giu year_quarter using "$dta/hires_sep_quarterly_sede.dta"
drop if _merge==2
drop _merge

* Merge in office-quarter data on demand
merge 1:1 cod_sede_giu year_quarter using "$dta/budged_prod_lord_cat_prod_2011_2017.dta"
assert _merge!=1
drop if _merge==2
drop _merge

egen cod_sede_giu_num=group(cod_sede_giu)
gen prod_sede2=produz_eq_sede/(forza_eq*3)
gen prod_sede3=prod_sede*disp/forza_eq

local var_list "assunzione_p sep_p fires_p cambio_sede_in_p cambio_sede_out_p"
foreach var of local var_list {
	assert `var'>=0 
	gen l`var'=ln(`var')
	gen a`var'=asinh(`var')
}

xtset cod_sede_giu_num year_quarter

local var_list "produz_eq_sede disp prod_sede giac_fin assenti formaz forza_eq forza straord qual_pp defLordo defLordo_omog pervenuto prod_sede3 prod_sede2"
foreach var of local var_list {
	sum `var', d
	_pctile `var', percentiles(0.5)
	replace `var'=`r(r1)' if `var'<=0
	replace `var'=0 if `var'<=0

	gen l`var'=ln(`var')
	gen a`var'=asinh(`var')
}

drop switch

gen correction=prod_sede3*3*forza_eq - produz_eq_sede
gen Y_full=produz_eq_sede+correction
gen lY_full=ln(Y_full)

* Generate macroareas
gen ripart_geo_sede="NW" if regione=="LIGURIA" | regione=="LOMBARDIA" | regione=="PIEMONTE" ///
	| regione=="VALLE D'AOSTA" | regione=="DCM MILANO"
replace ripart_geo_sede="NE" if regione=="EMILIA ROMAGNA" | regione=="FRIULI VENEZIA GIULIA" | regione=="TRENTINO ALTO ADIGE" ///
	| regione=="VENETO"
replace ripart_geo_sede="CENTER" if regione=="LAZIO" | regione=="DCM ROMA" | regione=="MARCHE" ///
	| regione=="TOSCANA" | regione=="UMBRIA" 
replace ripart_geo_sede="SOUTH" if regione=="ABRUZZO" | regione=="BASILICATA" | regione=="CAMPANIA" ///
	| regione=="CALABRIA" | regione=="DCM NAPOLI" |  regione=="PUGLIA" | regione=="MOLISE"
replace ripart_geo_sede="ISLANDS" if regione=="SARDEGNA" | regione=="SICILIA" 


replace ripartizionegeografica="CENTER" if ripartizionegeografica=="Centro"
replace ripartizionegeografica="ABROAD OR MISSING" if ripartizionegeografica=="EStero o Missing"
replace ripartizionegeografica="ISLANDS" if ripartizionegeografica=="Isole"
replace ripartizionegeografica="NE" if ripartizionegeografica=="Nord-est"
replace ripartizionegeografica="NW" if ripartizionegeografica=="Nord-ovest"
replace ripartizionegeografica="SOUTH" if ripartizionegeografica=="Sud"

gen sede_sud_isol=1 if regione=="ABRUZZO" | regione=="MOLISE" | regione=="CAMPANIA" ///
	| regione=="BASILICATA" | regione=="PUGLIA" | regione=="CALABRIA" | regione=="SICILIA" | ///
	regione=="SARDEGNA" | regione=="DCM NAPOLI"
replace sede_sud_isol=0 if sede_sud_isol==.	

gen sede_nord=1 if regione=="VALLE D'AOSTA" | regione=="PIEMONTE" | regione=="LOMBARDIA" | regione=="VENETO" ///
	| regione=="LIGURIA" | regione=="FRIULI VENEZIA GIULIA" | regione=="TRENTINO ALTO ADIGE" | regione=="EMILIA ROMAGNA" | ///
	regione=="DCM MILANO" 
replace sede_nord=0 if sede_nord==.

gen sede_centro=1 if regione=="TOSCANA" | regione=="LAZIO" | regione=="MARCHE" ///
	| regione=="UMBRIA" | regione=="DCM ROMA" 
replace sede_centro=0 if sede_centro==.	


gen aaa=1 if sede_nord==1 | sede_centro==1 | sede_sud_isol==1
assert aaa!=.
drop aaa

gen geo2=1 if sede_nord==1 | sede_centro==1
replace geo2=0 if sede_sud_isol==1

* Generate index for the subset of obs that do not have missing values
gen super_mis=.
local var_list "produz_eq_sede disp prod_sede prod_sede3 giac_fin assenti formaz forza_eq straord defLordo defLordo_omog pervenuto assunzione sep fires cambio_sede_in cambio_sede_out sep_pens_58 quits_58 sep_pens_60 quits_60 pass_inpdap arrivo uscita manager_id2"
foreach var of local var_list {
	replace super_mis=1 if `var'==.
}

* Indicator for any switch (the first year of each office is considered a switch)
bys cod_sede_giu_num (anno quarter): gen switch=1 if manager_id2!=manager_id2[_n-1]
* Indicator for a switch (the first year of each office is not considered a switch)
bys cod_sede_giu_num (anno quarter): gen counter=_n
bys cod_sede_giu_num (anno quarter): gen switch_nofirst=switch
replace switch_nofirst=. if counter==1

* This indicator excludes the first quarter of each switch
gen exlude_p0=(switch_nofirst==1)

* Save connected sets (i.e., islands)
preserve
	drop if manager_id2==.
	drop if exlude_p0==1
	a2group, individual(manager_id2) unit(cod_sede_giu_num) groupvar(island)
	keep manager_id2 island
	duplicates drop
	save "$tempfiles/island_full.dta", replace
restore

* Merge in connected sets
merge m:1 manager_id2 using "$tempfiles/island_full.dta"
assert _merge!=2
drop _merge

egen manager_by_office=group(manager_id2 cod_sede_giu_num)
gen quarter_switch=(switch==1)

* Generate asinh
local to_change "pervenuto1 defLordo1 pervenuto2 defLordo2 pervenuto3 defLordo3 pervenuto4 defLordo4 pervenuto5 defLordo5 pervenuto6 defLordo6 pervenuto7 defLordo7 pervenuto8 defLordo8 pervenuto9 defLordo9 pervenuto10 defLordo10 pervenuto11 defLordo11 pervenuto12 defLordo12"
foreach var of local to_change {
	gen a`var'= asinh(`var') 
	}

* Generate mover indicator
bys manager_id2 (year_quarter): gen obs=_n
bys manager_id2 (year_quarter): gen temp=1 if cod_sede_giu!=cod_sede_giu[_n-1] & obs!=1

bys manager_id2: egen temp2=total(temp)
replace temp2=. if manager_id2==.

gen mover=(temp2>0)
replace mover=. if temp2==.

gen geo_south_isl=geo_sud+geo_isl

* Rescale the variables
gen pervenuto_K=pervenuto/1000
gen giac_fin_K=giac_fin/1000
gen produz_eq_sede_K=produz_eq_sede/1000
gen abs_rate=assenti/forza_eq

egen cod_regione_num=group(cod_regione)

* I assume that overtime is paid 30% more than a regular hour
gen wage_1_30=(forza_eq- assenti - formaz)*1+straord*1.3


foreach var of varlist wage_1_30 {
	gen l`var'=ln(`var')
	gen a`var'=asinh(`var')
}
		
save "$tempfiles/master_data.dta", replace

