
************ COUNTERFACTUAL EXERCISES

*** COUNTERFACTUAL EXERCISE 1: Optimal assignment of managers to offices
use "$tempfiles/master_data_fe.dta", clear

merge m:1 manager_id2 using "$tempfiles/manager_fe_full.dta"
assert _merge!=2
drop _merge

merge m:1 manager_id2 using "$tempfiles/island_full.dta"
assert _merge!=2
drop _merge

gen t=year_quarter
keep if t==226 

gen b=1
bys island : egen bb=total(b)
drop if island==.
drop if bb<5 

keep sh_estimate lprod_sede3 prod_sede3 produz_eq_sede lproduz_eq_sede man_FE_lprod_sede3 sede_FE_lprod_sede3 cod_sede_giu year_quarter manager_id2 forza_eq island exo_strict

* Counterfactual estimates of manager FE
preserve 
	keep sh_estimate island
	bys island (sh_estimate): gen key=_n
	rename sh_estimate sh_estimate_counter
	save "$tempfiles/managers_FE_tomerge.dta", replace
restore

gen expo=exp(sede_FE_lprod_sede3)*forza_eq
bys island (expo): gen key=_n

merge 1:1 key island using "$tempfiles/managers_FE_tomerge.dta"
assert _merge==3
drop _merge

gen p_old=exp(sh_estimate)*exp(sede_FE_lprod_sede3)
gen p_new=exp(sh_estimate_counter)*exp(sede_FE_lprod_sede3)
egen p_old_total=total(p_old*forza_eq)
egen p_new_total=total(p_new*forza_eq)
gen P_change=(p_new_total-p_old_total)/p_old_total
sum P_change


*** COUNTERFACTUAL EXERCISE 2: Replacing the worse 20% of managers with the median manager
use "$tempfiles/master_data_fe.dta", clear

merge m:1 manager_id2 using "$tempfiles/manager_fe_full.dta"
assert _merge!=2
drop _merge

merge m:1 manager_id2 using "$tempfiles/island_full.dta"
assert _merge!=2
drop _merge

gen t=year_quarter
keep if t==226 

gen b=1
bys island : egen bb=total(b)
drop if island==.
drop if bb<5 

keep sh_estimate lprod_sede3 prod_sede3 produz_eq_sede lproduz_eq_sede man_FE_lprod_sede3 sede_FE_lprod_sede3 cod_sede_giu year_quarter manager_id2 forza_eq island exo_strict

* Counterfactual estimates of manager FE
preserve 
	keep sh_estimate manager_id2 island
	gen temp =sh_estimate
	duplicates drop

	egen group=group(island)
	su group, meanonly

	gen q_50=.
	gen q=.
	forval i = 1/`r(max)' {
		sum sh_estimate if group == `i', d
		replace q_50 = `r(p50)' if group == `i'
		xtile q_temp = sh_estimate if group == `i', nquantiles(5)
		replace q = q_temp if group == `i'
		drop q_temp
	 }

	replace sh_estimate=q_50 if q==1
	rename sh_estimate sh_estimate_counter
	save "$tempfiles/managers_FE_tomerge.dta", replace
restore

merge m:1 manager_id2 using "$tempfiles/managers_FE_tomerge.dta"
assert _merge==3
drop _merge

gen expo=exp(sede_FE_lprod_sede3)*forza_eq

gen p_old=exp(sh_estimate)*exp(sede_FE_lprod_sede3)
gen p_new=exp(sh_estimate_counter)*exp(sede_FE_lprod_sede3)
egen p_old_total=total(p_old*forza_eq)
egen p_new_total=total(p_new*forza_eq)
gen P_change=(p_new_total-p_old_total)/p_old_total
sum P_change

**** COUNTERFACTUAL EXERCISE 3: Optimal assignment of managers to offices + replacing the worse 20%
use "$tempfiles/master_data_fe.dta", clear

merge m:1 manager_id2 using "$tempfiles/manager_fe_full.dta"
assert _merge!=2
drop _merge

merge m:1 manager_id2 using "$tempfiles/island_full.dta"
assert _merge!=2
drop _merge

gen t=year_quarter
keep if t==226 

gen b=1
bys island : egen bb=total(b)
drop if island==.
drop if bb<5 

keep sh_estimate lprod_sede3 prod_sede3 produz_eq_sede lproduz_eq_sede man_FE_lprod_sede3 sede_FE_lprod_sede3 cod_sede_giu year_quarter manager_id2 forza_eq island exo_strict

* Counterfactual estimates of manager FE
preserve 
	keep sh_estimate island
	egen group=group(island)
	su group, meanonly

	gen q_50=.
	gen q=.
	forval i = 1/`r(max)' {
		sum sh_estimate if group == `i', d
		replace q_50 = `r(p50)' if group == `i'
		xtile q_temp = sh_estimate if group == `i', nquantiles(5)
		replace q = q_temp if group == `i'
		drop q_temp
	 }

	replace sh_estimate=q_50 if q==1
	bys island (sh_estimate): gen key=_n	
	rename sh_estimate sh_estimate_counter
	save "$tempfiles/managers_FE_tomerge.dta", replace
restore

gen expo=exp(sede_FE_lprod_sede3)*forza_eq
bys island (expo): gen key=_n

merge 1:1 key island using "$tempfiles/managers_FE_tomerge.dta"
assert _merge==3
drop _merge

gen p_old=exp(sh_estimate)*exp(sede_FE_lprod_sede3)
gen p_new=exp(sh_estimate_counter)*exp(sede_FE_lprod_sede3)
egen p_old_total=total(p_old*forza_eq)
egen p_new_total=total(p_new*forza_eq)
gen P_change=(p_new_total-p_old_total)/p_old_total
sum P_change

**** COUNTERFACTUAL EXERCISE 4: Random assignment
clear
set obs 1000
gen P_change_A=.
save "$tempfiles/Counterfactual_random.dta", replace


use "$tempfiles/master_data_fe.dta", clear

merge m:1 manager_id2 using "$tempfiles/manager_fe_full.dta"
assert _merge!=2
drop _merge

merge m:1 manager_id2 using "$tempfiles/island_full.dta"
assert _merge!=2
drop _merge

gen t=year_quarter
keep if t==226 

gen b=1
bys island : egen bb=total(b)
drop if island==.
drop if bb<5 

keep sh_estimate lprod_sede3 prod_sede3 produz_eq_sede lproduz_eq_sede man_FE_lprod_sede3 sede_FE_lprod_sede3 cod_sede_giu year_quarter manager_id2 forza_eq island exo_strict

bys island (cod_sede_giu): gen key=_n
set seed 1234

forval i=1(1)1000  {

	cap drop *counter p_new p_old P_change expo p_old_total p_new_total
	* Counterfactual estimates of manager FE
	preserve 
		keep sh_estimate island
		gen u=runiform()
		bys island (u): gen key=_n
		rename sh_estimate sh_estimate_counter
		save "$tempfiles/managers_FE_tomerge.dta", replace
	restore

	gen expo=exp(sede_FE_lprod_sede3)*forza_eq

	merge 1:1 key island using "$tempfiles/managers_FE_tomerge.dta"
	assert _merge==3
	drop _merge

	** This is new
	gen p_old=exp(sh_estimate)*exp(sede_FE_lprod_sede3)
	gen p_new=exp(sh_estimate_counter)*exp(sede_FE_lprod_sede3)
	
	egen p_old_total=total(p_old*forza_eq)
	egen p_new_total=total(p_new*forza_eq)
	gen P_change=(p_new_total-p_old_total)/p_old_total
	sum P_change
	local P_change_mean=r(mean)

	preserve
		use "$tempfiles/Counterfactual_random.dta", clear
		replace P_change_A=`P_change_mean' if _n==`i'
		save "$tempfiles/Counterfactual_random.dta", replace
	restore	
	
}

use "$tempfiles/Counterfactual_random.dta", clear
sum*
