	
*********** FIGURE 1

use "$tempfiles/master_data_fe_expanded.dta", clear

preserve
	keep if event_time>=${lower_bound} & event_time<=${upper_bound}
	
	* De-trend log productivity
	reghdfe lprod_sede3 if treated==1, absorb(i.quarter#i.cod_sede_giu2_num c.year_quarter#i.cod_regione_num, savefe) keepsingleton resid(res_detr)

	* Deifine tertiles of Delta M
	xtile d_m_FE_mean_tertile = d_m_FE_mean, nq(3)
	
	* Collapse the de-trended log productivity into three groups
	collapse (mean) res_detr*  (sd) sd=res_detr (count) N=res_detr, by(event_time d_m_FE_mean_tertile)

	* Construct CI
	gen u_ci=res_detr+1.96*(sd/sqrt(N))
	gen l_ci=res_detr-1.96*(sd/sqrt(N))

	assert event_time!=.
	gen post=(event_time>=0)
	bys d_m_FE_mean_tertile post: egen mean_p=mean(res_detr)

	global upper_bound_graphs=${upper_bound}+1
	global lower_bound_graphs=${lower_bound}-1

	sort d_m_FE_mean_tertile event_time

	* Graph
	twoway (line mean_p event_time if d_m_FE_mean_tertile==1, lpattern(solid) lcolor(green) lwidth(medthick)) ///
		(rcap u_ci l_ci event_time if d_m_FE_mean_tertile==1, lcolor(green)) ///
		(scatter res_detr event_time if d_m_FE_mean_tertile==1, msymbol(O) mcolor(green)) ///
		(line mean_p event_time if d_m_FE_mean_tertile==2, lpattern(dot) lcolor(orange_red) lwidth(medthick)) ///
		(rcap u_ci l_ci event_time if d_m_FE_mean_tertile==2, lcolor(orange_red)) ///
		(scatter res_detr event_time if d_m_FE_mean_tertile==2, msymbol(T) mcolor(orange_red) msize(medium)) ///
		(line mean_p event_time if d_m_FE_mean_tertile==3, lpattern(dash) lcolor(navy) lwidth(medthick)) ///
		(rcap u_ci l_ci event_time if d_m_FE_mean_tertile==3, lcolor(navy)) ///
		(scatter res_detr event_time if d_m_FE_mean_tertile==3, msymbol(D) mcolor(navy) msize(medium)), ///
		legend(order(3 "1st Tercile Delta M" 6 "2nd Tercile Delta M" 9 "3rd Tercile Delta M")) xline(-0.5, lcolor(gs6)) ///
		xtitle("Quarter") ytitle("Mean Ln(P)") xscale(range(${lower_bound_graphs}(1)${upper_bound_graphs})) ///
		yscale(range(-0.2 0.2)) ymtick(-0.2(0.1)0.2) ylabel(-0.2(0.1)0.2)
	graph export "$tables/Figure1.eps", replace	

restore
