
*********** ESTIMATE THE MANAGER EFFECTS
	
use "$tempfiles/master_data.dta", clear
	
* Estimate the manager and office FE
local var_list "lprod_sede3"	
foreach var of local var_list{
	
	set seed 1234
	reghdfe `var' if manager_id2!=. & exlude_p0!=1, absorb(man_FE_`var'=manager_id2 ///
		sede_FE_`var'=cod_sede_giu_num time_FE_`var'=year_quarter island, savefe) ///
		keepsingleton resid(r_`var')
	
	rename man_FE_`var' man_FE_`var'_old
}

* Assign Manager and Office FE to the observations that were not included in the previous regression
	bys manager_id2: egen man_fe_temp=mean(man_FE_lprod_sede3) 
drop man_FE_lprod_sede3
rename man_fe_temp man_FE_lprod_sede3
bys cod_sede_giu: egen sede_fe_temp=mean(sede_FE_lprod_sede3)
drop sede_FE_lprod_sede3
rename sede_fe_temp sede_FE_lprod_sede3


* Indicator for a switch (excluding the first year for every office) for which I could compute the FE using the split sample, AND
*	the manager was in charge for (at least) one year before, and the new manager stays in charge for (at least) 6 quarters after
bys cod_sede_giu_num (anno quarter): gen switch_fe_4q_6q=1 ///
	if man_FE_lprod_sede3!=. & man_FE_lprod_sede3[_n-1]!=. ///
	& manager_id2!=manager_id2[_n-1] ///
	& manager_id2[_n-1]==manager_id2[_n-2] & manager_id2[_n-1]==manager_id2[_n-3] & manager_id2[_n-1]==manager_id2[_n-4] ///
	& manager_id2==manager_id2[_n+1] & manager_id2==manager_id2[_n+2] & manager_id2==manager_id2[_n+3] & manager_id2==manager_id2[_n+4] ///
	& manager_id2==manager_id2[_n+5] & manager_id2==manager_id2[_n+6] ///
	& prod_sede!=. & prod_sede[_n-1]!=. & prod_sede[_n-2]!=. & prod_sede[_n-3]!=. & prod_sede[_n-4]!=. ///
	& prod_sede[_n+1]!=. & prod_sede[_n+2]!=. & prod_sede[_n+3]!=. & prod_sede[_n+4]!=. & prod_sede[_n+5]!=. & prod_sede[_n+6]!=.

	* Indicator for a switch (excluding the first year for every office) for which
*	the manager was in charge for (at least) one year before, and the new manager stays in charge for (at least) 5 quarters after
bys cod_sede_giu_num (anno quarter): gen switch4q_3q=1 if switch_nofirst==1 & manager_id2!=. & manager_id2[_n-1]!=. ///
	& manager_id2[_n-1]==manager_id2[_n-2] & manager_id2[_n-1]==manager_id2[_n-3] & manager_id2[_n-1]==manager_id2[_n-4] ///
	& manager_id2==manager_id2[_n+1] & manager_id2==manager_id2[_n+2] & manager_id2==manager_id2[_n+3] ///
	& prod_sede!=. & prod_sede[_n-1]!=. & prod_sede[_n-2]!=. & prod_sede[_n-3]!=. & prod_sede[_n-4]!=. ///
	& prod_sede[_n+1]!=. & prod_sede[_n+2]!=. & prod_sede[_n+3]!=. 

* Indicator for a switch (excluding the first year for every office) for which
*	the manager was in charge for (at least) one year before, and the new manager stays in charge for (at least) 6 quarters after
bys cod_sede_giu_num (anno quarter): gen switch4q_6q=1 if switch_nofirst==1 & manager_id2!=. & manager_id2[_n-1]!=. ///
	& manager_id2[_n-1]==manager_id2[_n-2] & manager_id2[_n-1]==manager_id2[_n-3] & manager_id2[_n-1]==manager_id2[_n-4] ///
	& manager_id2==manager_id2[_n+1] & manager_id2==manager_id2[_n+2] & manager_id2==manager_id2[_n+3] & manager_id2==manager_id2[_n+4] ///
	& manager_id2==manager_id2[_n+5] & manager_id2==manager_id2[_n+6] ///
	& prod_sede!=. & prod_sede[_n-1]!=. & prod_sede[_n-2]!=. & prod_sede[_n-3]!=. & prod_sede[_n-4]!=. ///
	& prod_sede[_n+1]!=. & prod_sede[_n+2]!=. & prod_sede[_n+3]!=. & prod_sede[_n+4]!=. & prod_sede[_n+5]!=. & prod_sede[_n+6]!=.  
	
xtset, clear
xtset cod_sede_giu_num year_quarter

* Notice that I am using all switches and the fixed effects estimated on the whole sample.
gen d_m_FE=man_FE_lprod_sede3-L.man_FE_lprod_sede3

* Save a dataset containing the manager and offie FE
save "$tempfiles/master_data_fe.dta", replace

keep manager_id2 man_FE_lprod_sede3
duplicates drop	
rename man_FE_lprod_sede3 sh_estimate
drop if manager_id2==.
save "$tempfiles/manager_fe_full.dta", replace

*********** EXPAND THE DATA
use "$tempfiles/master_data_fe.dta", clear

bys cod_sede_giu: egen ${shock_indicator_notfixed}_tot=total(${shock_indicator_notfixed})
bys cod_sede_giu: egen ${shock_indicator_notfixed}_tot_mean=mean(${shock_indicator_notfixed}_tot) 

assert ${shock_indicator_notfixed}_tot_mean<=3 |  ${shock_indicator_notfixed}_tot_mean==.

expand  2 if ${shock_indicator_notfixed}_tot_mean==2
expand  3 if ${shock_indicator_notfixed}_tot_mean==3 

duplicates tag *, gen(exp)
replace exp=exp+1

bys cod_sede_giu anno quarter: gen counter1=_n
tostring counter1, replace
gen cod_sede_giu2=cod_sede_giu+counter1

* This counter indexes the order of the new ids (e.g. OlD id =1000, now the ids become 10001, 10002, and 10003.)
bys ${shock_indicator_notfixed_nofe} cod_sede_giu anno quarter (counter1): gen counter2=sum(${shock_indicator_notfixed}) 
* This counter indexes the order of the shocks within each cod_sede_giu2
bys ${shock_indicator_notfixed_nofe} cod_sede_giu2 (anno quarter): gen counter3=sum(${shock_indicator_notfixed}) 

gen ${shock_indicator_notfixed}_fixed=${shock_indicator_notfixed} if exp==1 // this variable does not change if I have not duplicated the records
replace ${shock_indicator_notfixed}_fixed=1 if exp==2 & ${shock_indicator_notfixed_nofe}==1 & counter2==1 & counter3==1 // if there are two shocks for a given office, I assign the first date to the first duplicate, and the second date to the second duplicate
replace ${shock_indicator_notfixed}_fixed=1 if exp==2 & ${shock_indicator_notfixed_nofe}==1 & counter2==2 & counter3==2
replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==1 & counter3==1 // if there are three shocks, I follow the same procedure explained above
replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==2 & counter3==2 
replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==3 & counter3==3 

xtset, clear
egen cod_sede_giu2_num=group(cod_sede_giu2)
xtset cod_sede_giu2_num year_quarter

** Generate the shock
* Substitute d0=shock I want to use
gen d0=$shock_indicator 
gen event_time=0 if d0==1
gen to_average=1 if d0==1
replace to_average=1 if F.d0==1
bys cod_sede_giu2 manager_id2: egen sample1=mean(to_average)
gen d_m_FE_shock=d_m_FE if $shock_indicator==1
bys cod_sede_giu2: egen d_m_FE_mean=mean(d_m_FE_shock)

* Generate the dummy variables and "Post" indicator
xtset
foreach i of numlist 1/26 {
		gen dp`i'=L`i'.d0
		replace dp`i'=0 if dp`i'==.
		replace event_time=`i' if dp`i'==1
		gen dm`i'=F`i'.d0
		replace dm`i'=0 if dm`i'==.
		replace event_time=-`i' if dm`i'==1

		gen dp`i'_M=dp`i'*d_m_FE_mean
		replace dp`i'_M=0 if dp`i'_M==.
		gen dm`i'_M=dm`i'*d_m_FE_mean
		replace dm`i'_M=0 if dm`i'_M==.

		label var dp`i' "`i'"
		label var dm`i' "-`i'"
		label var dp`i'_M "`i'* $\Delta M$"
		label var dm`i'_M "-`i'* $\Delta M$"
	}

replace d0=0 if d0==.
gen d0_M=d0*d_m_FE_mean
replace d0_M=0 if d0_M==.
label var d0_M "0 * $\Delta M$"

bys cod_sede_giu2_num: egen treated=total(d0)
assert treated==1 | treated==0

gen d_agg=1 if event_time>=0 & event_time!=.
replace d_agg=0 if d_agg==.
gen d_agg_M=d_agg*d_m_FE_mean
replace d_agg_M=0 if d_agg_M==.
label var d_agg "Post"
label var d_agg_M "Post* $\Delta M$"

* Bin up the end points
local lower_bin=abs(${lower_bound})+1
local upper_bin=${upper_bound}+1

foreach num of numlist `upper_bin'/26 {
	replace dp`upper_bin'=1 if dp`num'==1
	replace dp`upper_bin'_M=d_m_FE_mean if dp`num'==1
}

foreach num of numlist `lower_bin'/26 {
	replace dm`lower_bin'=1 if dm`num'==1
	replace dm`lower_bin'_M=d_m_FE_mean if dm`num'==1
}

* Save an expanded dataset containing the manager and offie FE
save "$tempfiles/master_data_fe_expanded.dta", replace
