

*********** TABLE 4

use "$tempfiles/master_data_fe.dta", clear


	* collapse at the yearly level
	preserve

		keep exlude_p0 year_quarter anno cod_sede_giu_num manager_id2 lprod_sede3

		* I assigned the manager as the one who was there for more quarters in a year
		bys cod_sede_giu anno: egen manager_id2_mode=mode(manager_id2)
		set seed 1234
		gen u=runiform()
		bys cod_sede_giu_num anno: egen u_max=max(u)
		gen manager_random=manager_id2 if u==u_max
		bys cod_sede_giu_num anno: egen manager_random_replace=mean(manager_random) if manager_id2_mode==.
		replace manager_id2_mode=manager_random_replace if manager_id2_mode==.
		drop manager_id2 manager_random*
		rename manager_id2_mode manager_id2

		drop if exlude_p0==1

		collapse manager_id2 lprod_sede3, by(cod_sede_giu_num anno)

		egen manager_by_office=group(manager_id2 cod_sede_giu_num)
		
		* column 1
		set seed 1234
		reghdfe lprod_sede3 if manager_id2!=., absorb(anno, savefe) keepsingleton
		estadd local sede_fe "No", replace
		estadd local time_fe "Yes", replace
		estadd local manager_fe "No", replace
		estadd local manager_office_fe "No", replace
		est sto lprod_sede3_1

		* column 2
		set seed 1234
		reghdfe lprod_sede3 if manager_id2!=., absorb(cod_sede_giu_num anno, savefe) keepsingleton
		estadd local sede_fe "Yes", replace
		estadd local time_fe "Yes", replace
		estadd local manager_fe "No", replace
		estadd local manager_office_fe "No", replace
		est sto lprod_sede3_2
		
		* column 3
		set seed 1234
		reghdfe lprod_sede3 i.manager_id2 if manager_id2!=., absorb(cod_sede_giu_num anno) keepsingleton
		estadd local sede_fe "Yes", replace
		estadd local time_fe "Yes", replace
		estadd local manager_fe "Yes", replace
		estadd local manager_office_fe "No", replace
		*estadd local connected_set_fe "Yes", replace
		est sto lprod_sede3_3
		
		* test
		anova lprod_sede3 manager_id2 cod_sede_giu_num anno
		test manager_id2
		estadd scalar Pval_manager = Ftail(r(df), r(df_r) , r(F)): lprod_sede3_3
		
		* column 4
		set seed 1234
		reghdfe lprod_sede3 if manager_id2!=., absorb(man_nos_FE_`var'=manager_id2 anno) keepsingleton
		estadd local sede_fe "No", replace
		estadd local time_fe "Yes", replace
		estadd local manager_fe "Yes", replace
		estadd local manager_office_fe "No", replace
		est sto lprod_sede3_5
		
		* test
		anova lprod_sede3 manager_id2 cod_sede_giu_num anno
		test manager_id2
		estadd scalar Pval_manager = Ftail(r(df), r(df_r) , r(F)): lprod_sede3_5
		
		* column 5
		set seed 1234
		reghdfe lprod_sede3 if manager_id2!=., absorb(manager_by_office anno) keepsingleton
		estadd local sede_fe "No", replace
		estadd local time_fe "Yes", replace
		estadd local manager_fe "No", replace
		estadd local manager_office_fe "Yes", replace
		est sto lprod_sede3_4
		
		

		esttab lprod_sede3_1 lprod_sede3_2 lprod_sede3_3 lprod_sede3_5 lprod_sede3_4 ///
			using "$tables/Table4.tex", label cells(b(star fmt(%9.2f)) se(par fmt(%9.2f)) t(par([ ]) fmt(%9.2f))) star(* 0.10 ** 0.05 *** 0.01) ///
			s(N r2 r2_a time_fe sede_fe manager_fe manager_office_fe Pval_manager, fmt(%9.0g %9.3f %9.3f %9.2f %9.3f) label("N" "R sq." "Adj. R sq." "Time FE" "Office FE" "Manager FE" "Manag-by-Office FE" "Pvalue")) ///
			obslast collabels(none) drop(*) ///
			mtitles("Ln(P)" "Ln(P)" "Ln(P)" "Ln(P)" "Ln(P)") ///
			title("Analysis of Variance of Productivity per Worker at INPS Offices") ///
			replace
			
	restore	
