
*********** TABLE 5

use "$tempfiles/master_data_fe.dta", clear

* Generate baseline office productivity
gen prod_temp=prod_sede3 if anno==2011
bys cod_sede_giu: egen prod0=mean(prod_temp)

* Generate baseline office FTE
gen forza_eq_temp=forza_eq if anno==2011
bys cod_sede_giu: egen forza_eq0=mean(forza_eq)

* Generate baseline output
gen prod_sede_temp=produz_eq_sede if anno==2011
bys cod_sede_giu: egen produz_eq_sede0=mean(prod_sede_temp)

* Generate change in the manager fixed effects
xtset
gen change_estimate=man_FE_lprod_sede3-L.man_FE_lprod_sede3

* Generate growth rates of productivity, output, and FTE
xtset
foreach var of varlist prod_sede3 produz_eq_sede forza_eq {
	gen gr_`var'_4q=(L.`var'-L5.`var')/L5.`var' if switch==1

	gen gr_`var'_3q=(L.`var'-L4.`var')/L4.`var' if switch==1

	gen gr_`var'_2q=(L.`var'-L3.`var')/L3.`var' if switch==1
	
	gen gr_`var'_1q=(L.`var'-L2.`var')/L2.`var' if switch==1

}

* label the variables
label var exo_strict "Main Office"
label var geo2 "North + Center"
label var prod0 "P (2011)"
label var produz_eq_sede0 "Y (2011)"
label var forza_eq0 "FTE (2011)"
label var gr_prod_sede3_4q "Growth Rate P - 1 yr"
label var gr_prod_sede3_2q "Growth Rate P - 2 q"
label var gr_prod_sede3_3q "Growth Rate P - 3 q"
label var gr_produz_eq_sede_4q "Growth Rate Y - 1 yr"
label var gr_produz_eq_sede_2q "Growth Rate Y - 2 q"
label var gr_produz_eq_sede_3q "Growth Rate Y - 3 q"
label var gr_forza_eq_4q "Growth Rate FTE - 1 yr"
label var gr_forza_eq_2q "Growth Rate FTE - 2 q"
label var gr_forza_eq_3q "Growth Rate FTE - 3 q"
label var prod_sede3 "P (t-1)"
label var produz_eq_sede "Y (t-1)"
label var forza_eq "FTE (t-1)"


* Generate indicator for switches with no missing values for the growth rates
gen no_mis=1 if switch_nofirst==1 & gr_prod_sede3_3q!=.
* Generate indicator for switches that have at least 4 quarter of data before the change in leadership
bys cod_sede_giu_num (anno quarter): gen switch_4pre_noman=1 ///
	if switch_nofirst==1 ///
	& prod_sede!=. & prod_sede[_n-1]!=. & prod_sede[_n-2]!=. & prod_sede[_n-3]!=. & prod_sede[_n-4]!=. 

xtset

* Column 1: the dependent variable is the estimated manager FE
areg man_FE_lprod_sede3 L.exo_strict L.geo2 L.prod0 L.produz_eq_sede0 L.forza_eq0 L.prod_sede3 L2.prod_sede3 L3.prod_sede3 L4.prod_sede3 ///
	L.produz_eq_sede L2.produz_eq_sede L3.produz_eq_sede L4.produz_eq_sede L.forza_eq L2.forza_eq L3.forza_eq L4.forza_eq ///
	gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q if switch_4pre_noman==1 & no_mis==1 & change_estimate!=., absorb(island) vce(cl cod_sede_giu)
est sto exo_move_bal1
estadd local cs_fe "Yes", replace

test L.exo_strict L.geo2 L.prod0 L.produz_eq_sede0 L.forza_eq0 L.prod_sede3 L2.prod_sede3 L3.prod_sede3 L4.prod_sede3 ///
	L.produz_eq_sede L2.produz_eq_sede L3.produz_eq_sede L4.produz_eq_sede L.forza_eq L2.forza_eq L3.forza_eq L4.forza_eq ///
	gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q
estadd scalar Pval1 = r(p)			

test gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q 
estadd scalar Pval2 = r(p)	

* Column 2: the dependent variable is the change in the estimated manager FE
areg change_estimate L.exo_strict L.geo2 L.prod0 L.produz_eq_sede0 L.forza_eq0 L.prod_sede3 L2.prod_sede3 L3.prod_sede3 L4.prod_sede3 ///
	L.produz_eq_sede L2.produz_eq_sede L3.produz_eq_sede L4.produz_eq_sede L.forza_eq L2.forza_eq L3.forza_eq L4.forza_eq ///
	gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q if switch_4pre_noman==1 & no_mis==1 & change_estimate!=., absorb(island) vce(cl cod_sede_giu)
est sto exo_move_bal2
estadd local cs_fe "Yes", replace

test L.exo_strict L.geo2 L.prod0 L.produz_eq_sede0 L.forza_eq0 L.prod_sede3 L2.prod_sede3 L3.prod_sede3 L4.prod_sede3 ///
	L.produz_eq_sede L2.produz_eq_sede L3.produz_eq_sede L4.produz_eq_sede L.forza_eq L2.forza_eq L3.forza_eq L4.forza_eq ///
	gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q
estadd scalar Pval1 = r(p)			

test gr_prod_sede3_3q gr_prod_sede3_2q gr_prod_sede3_1q gr_produz_eq_sede_3q gr_produz_eq_sede_2q gr_produz_eq_sede_1q gr_forza_eq_3q ///
	gr_forza_eq_2q gr_forza_eq_1q 
estadd scalar Pval2 = r(p)

* Export table
esttab exo_move_bal1 exo_move_bal2 ///
	using "$tables/Table5.tex", label cells("b(star fmt(%9.3f)) se(par fmt(%9.3f))") star(* 0.10 ** 0.05 *** 0.01) ///
	s(N r2 r2_a cs_fe Pval1 Pval2, fmt(%9.0g %9.3f %9.3f %9.3f %9.3f) label("N" "R sq." "Adj. R sq." "CS FE" "P-value (All)" "P-value (Growth Rates)")) ///
	obslast collabels(none) drop(_cons) ///
	mtitles("Manager FE" "Change in Manager FE") ///
	title("Can Observables Predict Incoming Manager FE?") ///
	replace
