
%% Table 6

% This codes performs the Andrews correction for the variance-covariance decomposition on the largest connected set.
% I thank Raffaele Saggio for sharing his code with me.


clear all
clc


full_data=csvread('Andrews_Matrix_excl0.csv');

F=sparse(csvread('F_excl0.csv'));
D=sparse(csvread('D_excl0.csv'));
y=csvread('y_excl0.csv');
t=sparse(csvread('T_excl0.csv'));


NSIM=10000;  

%% Step 1: Perform AKM
J=size(F,2); 
T=size(t,2);
NT=size(F,1);
S=speye(J-1);
S_time=speye(T-1);

S=[S;sparse(-zeros(1,J-1))];  %NT+Jx+J-1 restriction matrix F*S=F(:,1:J-1)
S_time=[S_time;sparse(-zeros(1,T-1))];
X=[D,F*S,t*S_time]; % the F*S gives the F matrix where its last rows are replaced by row of zeros, 
%this is because we have to drop one firm FE due to multicollinearity
% X is the design matrix of D and F (with the last row replaced by zeros)
xx=X'*X;
xy=X'*y;
% Cholesky factorization
L=ichol(xx,struct('type','ict','droptol',1e-2,'diagcomp',.1));
b=pcg(xx,xy,1e-10,1000,L,L');
N=size(D,2);
% the first N elements are the worker FE
ahat=b(1:N);
% from N+1 to N+J-1 these are the firm FE
ghat=b(N+1:N+J-1);
% from N+J to end this are time FE
that=b(N+J:N+J-1+T-1);
xb=X*b;
r=y-xb;
dof=NT-J-N+1;
sigma_mse=(sum(r.^2)/dof);
%% Step 2: Correct
Vsel_pe=zeros(NSIM,1);
Vsel_fe=zeros(NSIM,1);
Vsel_te=zeros(NSIM,1);
Vsel_cov=zeros(NSIM,1);
Vsel_cov_te_fe=zeros(NSIM,1);
Vsel_cov_te_pe=zeros(NSIM,1);
for s=1:NSIM 
xsimul=rand(size(xx,1),1);
x=1.*(xsimul>0.5)-1.*(xsimul<=0.5); %Rademacher weights
[first flag]=pcg(xx,x,1e-8,1000,L,L');
%% now keep only the relevant solution from pcg and from drawn x's: Var(FE)
first_fe=first(N+1:N+J-1,:); %these are the v's for the firm FE on page 7 of Gaure (2014)
vecx_fe=x(N+1:N+J-1); %these are the x's for the firm FE on page 7 of Gaure (2014)
second_fe=F*S*vecx_fe-mean(F*S*vecx_fe);
COV=cov(second_fe,F*S*first_fe);
Vsel_fe(s)=COV(1,2);
% this is just to show that I could have computed the covariance by
% multiplying the matrixes (a is very similar to COV)
a = (second_fe'*F*S*first_fe)/NT;
%% now keep only the relevant solution from pcg and from drawn x's: Var(TE)
first_fe=first(N+J:N+J-1+T-1,:); %these are the v's for the time FE on page 7 of Gaure (2014)
vecx_fe=x(N+J:N+J-1+T-1); %these are the x's for the firm FE on page 7 of Gaure (2014)
second_fe=t*S_time*vecx_fe-mean(t*S_time*vecx_fe);
COV=cov(second_fe,t*S_time*first_fe);
Vsel_te(s)=COV(1,2);
%% now keep only the relevant solution from pcg and from drawn x's: Var(PE)
first_pe=first(1:N,:);
vecx_pe=x(1:N);
second_pe=D*vecx_pe-mean(D*vecx_pe);
COV=cov(second_pe,D*first_pe);
Vsel_pe(s)=COV(1,2);
%% now keep only the relevant solution from pcg and from drawn x's: COV(PE,FE)
first_cov=first(N+1:N+J-1,:);
vecx_cov=x(1:N);
second_cov=D*vecx_cov-mean(D*vecx_cov);
COV=cov(second_cov,F*S*first_cov);
Vsel_cov(s)=COV(1,2);
%% now keep only the relevant solution from pcg and from drawn x's: COV(TE,FE)
first_cov=first(N+1:N+J-1,:);
vecx_cov=x(N+J:N+J-1+T-1);
second_cov=t*S_time*vecx_cov-mean(t*S_time*vecx_cov);
COV=cov(second_cov,F*S*first_cov);
Vsel_cov_te_fe(s)=COV(1,2);
%% now keep only the relevant solution from pcg and from drawn x's: COV(TE,PE)
first_cov=first(1:N,:);
vecx_cov=x(N+J:N+J-1+T-1);
second_cov=t*S_time*vecx_cov-mean(t*S_time*vecx_cov);
COV=cov(second_cov,D*first_cov);
Vsel_cov_te_pe(s)=COV(1,2);
end
%% Don't foreget to multiply by MSE
correction_fe=sigma_mse*(mean(Vsel_fe));
correction_pe=sigma_mse*(mean(Vsel_pe));
correction_te=sigma_mse*(mean(Vsel_te));
correction_cov=sigma_mse*(mean(Vsel_cov));
correction_cov_te_fe=sigma_mse*(mean(Vsel_cov_te_fe));
correction_cov_te_pe=sigma_mse*(mean(Vsel_cov_te_pe));
%% Get uncorrected variance or covariance.
var_uncorrected_fe=var(F*S*ghat)
var_uncorrected_pe=var(D*ahat)
var_uncorrected_te=var(t*S_time*that)
var_uncorrected_cov=cov(D*ahat,F*S*ghat);
var_uncorrected_cov=var_uncorrected_cov(1,2)
var_uncorrected_cov_te_fe=cov(t*S_time*that,F*S*ghat);
var_uncorrected_cov_te_fe=var_uncorrected_cov_te_fe(1,2)
var_uncorrected_cov_te_pe=cov(t*S_time*that,D*ahat);
var_uncorrected_cov_te_pe=var_uncorrected_cov_te_pe(1,2)
%% calculate adjusted variance.
var_corrected_fe=var_uncorrected_fe-correction_fe
var_corrected_pe=var_uncorrected_pe-correction_pe
var_corrected_te=var_uncorrected_te-correction_te
var_corrected_cov=var_uncorrected_cov-correction_cov
var_corrected_cov_te_fe=var_uncorrected_cov_te_fe-correction_cov_te_fe
var_corrected_cov_te_pe=var_uncorrected_cov_te_pe-correction_cov_te_pe


