
*********** TABLE 8, TABLE 9, and APPENDIX TABLE G1

if  ${bootstrap} ==1 {
	* Set the Number of Iterations
	global iterations=1000
	global weights "weight_b"
	global b "_boot_${counter_iter}"
	
	
	* Erase all files in the folder
	local files : dir "$tempfiles/bootstrap_weights" files "*.dta"
	foreach file in `files' {
		di "`file'"
		rm "$tempfiles/bootstrap_weights/`file'"	
	}

	* I generate a set of random numbers taken from an exponential mu=1 and sigma^2=1
	set seed 595302
	forvalues i = 1(1)$iterations {
		clear
		set obs 12668
		gen obs=_n
		gen weight_b=rexponential(1)
		compress
		save "$tempfiles/bootstrap_weights/bootstrap_weights_`i'.dta", replace
	}
}
	
if  ${bootstrap} ==0 {
	
	global iterations=1
	global weights "weight_nob"
	global b ""
}


***** BEGINNING OF ITERATIONS. IF I BOOTSTRAP I PERFORM THESE CALCULATIONS MANY TIMES
*		WHEN I DO NOT BOOTSTRAP, THEN ONLY ONCE

global counter_iter=0
forvalues i = 1(1)$iterations {
	di "ITERATION `i'" 
	
	global counter_iter=${counter_iter}+1
	di " COUNTER ${counter_iter}"
	
	clear
	* Set of indicators from event studies balanced on M4 P6
	local excluded_indicators "ex_m1_m4 ex_m1_m3 ex_m1_m2 ex_m1_p0 ex_m1_p1 ex_m1_p2 ex_m1_p3 ex_m1_p4 ex_m1_p5 ex_m1_p6"
	foreach indicator of local excluded_indicators {
		
		global first=substr("`indicator'",4,2)
		global f=substr("`indicator'",5,1)
		global second=substr("`indicator'",7,2)
		global s=substr("`indicator'",8,1)
		global third=substr("`indicator'",10,2)
		di "INDICATOR: ${first} ${second} ${third}"

		cap drop manager_id2_exc ${shock_indicator_notfixed}_tot ${shock_indicator_notfixed}_tot_mean ${shock_indicator_notfixed}_fixed counter* ///
			d0 to_average sample1 dp* dm* d_m_FE_* d_m_FE_mean d_agg* man_FE_man_FE_lprod_sede3_exc m_FE_excl 

		use "$tempfiles/master_data_fe.dta", clear
		drop if cod_sede_giu==""

		gen asep_pens_nc_p=asinh(sep_pens_nc_p)		
		gen sep_young=sep- sep_pens_nc_p
		assert sep_young>=0
		gen asep_young=asinh(sep_young)

		foreach var of varlist assunzione_p sep_p fires_p cambio_sede_in_p cambio_sede_out_p sep_pens_nc_p sep sep_young {
			bys cod_sede_giu_num: gen `var'_c=sum(`var')
			gen a`var'_c=asinh(`var'_c)
			gen l`var'_c=ln(`var'_c)
		}

		xtset
		drop obs
		gen obs=_n
		
		if  ${bootstrap} ==1 {
			di "MERGE WEIGHTS"
			merge 1:1 obs using "$tempfiles/bootstrap_weights/bootstrap_weights_${counter_iter}.dta"
			assert _merge==3
			drop _merge
			assert weight_b>=0
			
			global b "_boot_${counter_iter}"
			
			
			*One weight per office and not per observation
			bys cod_sede_giu_num (year_quarter): gen obs2=_n
			gen weight_temp=weight_b if obs2==1
			bys cod_sede_giu_num: egen weight_b2=mean(weight_temp)
			
			drop obs2 weight_b
			rename weight_b2 weight_b
		}
		
		if  ${bootstrap} ==0 {
			gen weight_nob=1
		}
		di "ITERATION `i'" 
		di " COUNTER ${counter_iter}"

		* Exclude -4 and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m6=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+6]==1
		* Exclude -4 and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m5=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+6]==1
		* Exclude -4 and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m4=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+4]==1
		* Exclude -3 and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m3=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+3]==1
		* Exclude -2 and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m2=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+2]==1
		* Exclude -1 and plus 1
		bys cod_sede_giu (year_quarter): gen ex_m1_p1=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-1]==1
		* Exclude -1 and plus 2
		bys cod_sede_giu (year_quarter): gen ex_m1_p2=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-2]==1
		* Exclude -1 and plus 3
		bys cod_sede_giu (year_quarter): gen ex_m1_p3=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-3]==1
		* Exclude -1 and plus 4
		bys cod_sede_giu (year_quarter): gen ex_m1_p4=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-4]==1
		* Exclude -1 and plus 5	
		bys cod_sede_giu (year_quarter): gen ex_m1_p5=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-5]==1
		* Exclude -1 and plus 6
		bys cod_sede_giu (year_quarter): gen ex_m1_p6=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-6]==1

		
		* Exclude -2,-1,4,5
		bys cod_sede_giu (year_quarter): gen ex_m1_m2_p4_p5=1 if ${shock_indicator_notfixed}[_n+2]==1 | ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-4]==1 | ${shock_indicator_notfixed}[_n-5]==1
		* Exclude -3, -2,and -1
		bys cod_sede_giu (year_quarter): gen ex_m1_m2_m3=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n+2]==1 | ${shock_indicator_notfixed}[_n+3]==1
		* Exclude -1,0,1
		bys cod_sede_giu (year_quarter): gen ex_m1_p0_p1=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}==1 | ${shock_indicator_notfixed}[_n-1]==1
		* Exclude -1,2,3
		bys cod_sede_giu (year_quarter): gen ex_m1_p2_p3=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-2]==1 | ${shock_indicator_notfixed}[_n-3]==1
		* Exclude -1,4,5
		bys cod_sede_giu (year_quarter): gen ex_m1_p4_p5=1 if ${shock_indicator_notfixed}[_n+1]==1 | ${shock_indicator_notfixed}[_n-4]==1 | ${shock_indicator_notfixed}[_n-5]==1			
		
		gen manager_id2_exc=manager_id2		
		xtset	
		replace manager_id2_exc=. if `indicator'==1 | exlude_p0==1 
		
		* Estimate the manager effects excluding three periods at a time
		local var_list "lprod_sede3"
		foreach var of local var_list{	
			* I have to include set seed otherwise reghdfe would estimate slightly different FE on every run
			set seed 1234
			reghdfe `var' if manager_id2!=. [aweight=${weights}], absorb(man_FE_`var'_exc2=manager_id2_exc cod_sede_giu_num year_quarter, savefe) keepsingleton
		
		}
		
		bys manager_id2: egen m_FE_excl=mean(man_FE_lprod_sede3_exc)
		xtset
		gen d_m_FE_excl=m_FE_excl-L.m_FE_excl
		
			
		* Because a few offices experience multiple shocks over the sample period, I duplicates those records and treat them as if they were
		*	different offices	
		bys cod_sede_giu: egen ${shock_indicator_notfixed}_tot=total(${shock_indicator_notfixed}) 
		bys cod_sede_giu: egen ${shock_indicator_notfixed}_tot_mean=mean(${shock_indicator_notfixed}_tot) 

		
		assert ${shock_indicator_notfixed}_tot_mean<=3 |  ${shock_indicator_notfixed}_tot_mean==. 
		expand  2 if ${shock_indicator_notfixed}_tot_mean==2
		expand  3 if ${shock_indicator_notfixed}_tot_mean==3 // this is no longer needed for now, i keep it if i will need it in the future

		* how many observations i have for each type
		duplicates tag *, gen(exp)
		replace exp=exp+1
		
		*** I have to generate the shock again because now all the observations that I have duplicated have multiple shocks. I want each
		***		duplicate to have a different shock
		* Generate the office identifier so that it takes a different value for every duplicate 
		bys cod_sede_giu anno quarter: gen counter1=_n
		tostring counter1, replace
		gen cod_sede_giu2=cod_sede_giu+counter1

		* This counter indexes the order of the new ids (e.g. OlD id =1000, now the ids become 10001, 10002, and 10003. The first new-id has)
		bys ${shock_indicator_notfixed_nofe} cod_sede_giu anno quarter (counter1): gen counter2=sum(${shock_indicator_notfixed}) 
		* This counter indexes the order of the shocks within each cod_sede_giu2
		bys ${shock_indicator_notfixed_nofe} cod_sede_giu2 (anno quarter): gen counter3=sum(${shock_indicator_notfixed}) 

		gen ${shock_indicator_notfixed}_fixed=${shock_indicator_notfixed} if exp==1 // this variable does not change if I have not duplicated the records
		replace ${shock_indicator_notfixed}_fixed=1 if exp==2 & ${shock_indicator_notfixed_nofe}==1 & counter2==1 & counter3==1 // if there are two shocks for a given office, I assign the first date to the first duplicate, and the second date to the second duplicate
		replace ${shock_indicator_notfixed}_fixed=1 if exp==2 & ${shock_indicator_notfixed_nofe}==1 & counter2==2 & counter3==2
		replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==1 & counter3==1 // if there are three shocks, I follow the same procedure explained above
		replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==2 & counter3==2 
		replace ${shock_indicator_notfixed}_fixed=1 if exp==3 & ${shock_indicator_notfixed_nofe}==1 & counter2==3 & counter3==3 
	
		xtset, clear
		egen cod_sede_giu2_num=group(cod_sede_giu2)
		xtset cod_sede_giu2_num year_quarter

		**** Generating the shock
		* Here I have to substitute d0=shock I want to use
		gen d0=$shock_indicator 
		gen event_time=0 if d0==1
		gen to_average=1 if d0==1
		replace to_average=1 if F.d0==1
		bys cod_sede_giu2 manager_id2: egen sample1=mean(to_average)
		* I create this additional variable which takes the value of the difference in manager FE only for the shocks I have selected.
		gen d_m_FE_shock=d_m_FE_excl if $shock_indicator==1
		bys cod_sede_giu2: egen d_m_FE_mean=mean(d_m_FE_shock)
		
		* Generate event time dummies
		xtset
		foreach j of numlist 1/26 {
				gen dp`j'=L`j'.d0
				replace dp`j'=0 if dp`j'==.
				replace event_time=`j' if dp`j'==1
				gen dm`j'=F`j'.d0
				replace dm`j'=0 if dm`j'==.
				replace event_time=-`j' if dm`j'==1

				gen dp`j'_M=dp`j'*d_m_FE_mean
				replace dp`j'_M=0 if dp`j'_M==.
				gen dm`j'_M=dm`j'*d_m_FE_mean
				replace dm`j'_M=0 if dm`j'_M==.

				label var dp`j' "`j'"
				label var dm`j' "-`j'"
				label var dp`j'_M "`j'* $\Delta M$"
				label var dm`j'_M "-`j'* $\Delta M$"
			}	

		replace d0=0 if d0==.
		gen d0_M=d0*d_m_FE_mean
		replace d0_M=0 if d0_M==.
		label var d0_M "0 * $\Delta M$"

		bys cod_sede_giu2_num: egen treated=total(d0)
		assert treated==1 | treated==0

		gen d_agg=1 if event_time>=0 & event_time!=.
		replace d_agg=0 if d_agg==.
		gen d_agg_M=d_agg*d_m_FE_mean
		replace d_agg_M=0 if d_agg_M==.
		label var d_agg "Post"
		label var d_agg_M "Post* $\Delta M$"

		* Bin up the end points
		local lower_bin=abs(${lower_bound})+1
		local upper_bin=${upper_bound}+1
		
		foreach num of numlist `upper_bin'/26 {
			replace dp`upper_bin'=1 if dp`num'==1
			replace dp`upper_bin'_M=d_m_FE_mean if dp`num'==1
		}

		foreach num of numlist `lower_bin'/26 {
			replace dm`lower_bin'=1 if dm`num'==1
			replace dm`lower_bin'_M=d_m_FE_mean if dm`num'==1
		}
		
		gen prod_temp=prod_sede3 if anno==2011
		bys cod_sede_giu2: egen prod0=mean(prod_temp)
			
		xtile prod0_quart = prod0, nq(4)
			gen prod0_lowerquart=1 if prod0_quart==1
			replace prod0_lowerquart=0 if prod0_lowerquart==. & prod0_quart!=.

		di "INDICATOR: `indicator'"
		if "`indicator'"!="ex_m1_m2" & "`indicator'"!="ex_m1_m3" & "`indicator'"!="ex_m1_m4" & "`indicator'"!="ex_m1_m5" & "`indicator'"!="ex_m1_m6"  & "`indicator'"!="ex_m1_p0" & "`indicator'"!="ex_m1_p1" & "`indicator'"!="ex_m1_p2"  & "`indicator'"!="ex_m1_p3" & "`indicator'"!="ex_m1_p4" & "`indicator'"!="ex_m1_p5" & "`indicator'"!="ex_m1_p6"{
			di "ERROR"
			ERROR
		
		}
		
	

		di "ITERATION `i'" 
		di " COUNTER ${counter_iter}"
			
		*** Exclude (m1, m2), (m1, m3), (m1, m4)
		if "`indicator'"=="ex_m1_m2" | "`indicator'"=="ex_m1_m3" | "`indicator'"=="ex_m1_m4" | "`indicator'"=="ex_m1_m5" | "`indicator'"=="ex_m1_m6" {
			di "${first} ${second}"
			
			* Generate First Differences
			xtset
			foreach y of varlist lprod_sede3 lproduz_eq_sede lforza_eq ldisp lwage_1_30 abs_rate aqual_pp aformaz astraord lY_full aassunzione_p_c afires_p_c acambio_sede_in_p_c acambio_sede_out_p_c lqual_pp lgiac_fin lpervenuto asep_young_c asep_pens_nc_p_c lprod_sede2 {
				gen fd_`y'= L${s}.`y'-L.`y' if event_time==0
			}

			* These variable names are too long, so I shorten them
			rename fd_acambio_sede_in_p_c fd_acamb_in_p_c
			rename fd_acambio_sede_out_p_c fd_acamb_out_p_c

	
			* Dep. variables
			foreach y in fd_lprod_sede3 fd_lY_full fd_lforza_eq fd_asep_pens_nc_p_c fd_aassunzione_p_c fd_afires_p_c fd_acamb_in_p_c fd_acamb_out_p_c fd_asep_young_c fd_abs_rate fd_aformaz fd_astraord fd_ldisp fd_lwage_1_30 fd_lqual_pp fd_lgiac_fin fd_lpervenuto fd_lprod_sede2 {
				
				reg  `y' d_m_FE_mean i.year_quarter i.geo2 i.exo_strict i.year_quarter#i.geo2 ///
					i.geo2#i.exo_strict i.prod0_quart##i.exo_strict ///
					if super_mis!=1 ///
					[aweight=${weights}], vce(cl cod_sede_giu2_num)
				parmest, saving("$tempfiles/Dp_Dm_`y'_${first}_${second}${b}.dta", replace)
				
				local b1_rf_`y'_d${second}:  di %9.3f round(_b[d_m_FE_mean],0.001)
				local se1_rf_`y'_d${second}: di %9.3f round(_se[d_m_FE_mean],0.001)
				local N_rf_`y'_d${second}=e(N)							
			}
		}


		*** Exclude (m1, p0)
		if "`indicator'"=="ex_m1_p0" {
			di "${first} ${second}"
			
			* Generate First Differences
			xtset
			foreach y of varlist lprod_sede3 lproduz_eq_sede lforza_eq ldisp lwage_1_30 abs_rate aqual_pp aformaz astraord lY_full aassunzione_p_c afires_p_c acambio_sede_in_p_c acambio_sede_out_p_c lqual_pp lgiac_fin lpervenuto asep_young_c asep_pens_nc_p_c lprod_sede2 {
				gen fd_`y'= F${s}.`y'-L.`y' if event_time==0
			}
			
			* These variable names are too long, so I shorten them
			rename fd_acambio_sede_in_p_c fd_acamb_in_p_c
			rename fd_acambio_sede_out_p_c fd_acamb_out_p_c

	
			* Dep. variables
			foreach y in fd_lprod_sede3 fd_lY_full fd_lforza_eq fd_asep_pens_nc_p_c fd_aassunzione_p_c fd_afires_p_c fd_acamb_in_p_c fd_acamb_out_p_c fd_asep_young_c fd_abs_rate fd_aformaz fd_astraord fd_ldisp fd_lwage_1_30 fd_lqual_pp fd_lgiac_fin fd_lpervenuto fd_lprod_sede2 {

				reg  `y' d_m_FE_mean i.year_quarter i.geo2 i.exo_strict i.year_quarter#i.geo2 ///
					i.geo2#i.exo_strict i.prod0_quart##i.exo_strict ///
					if super_mis!=1 ///
					[aweight=${weights}], vce(cl cod_sede_giu2_num)
				parmest, saving("$tempfiles/Dp_Dm_`y'_${first}_${second}${b}.dta", replace)
				
				local b1_rf_`y'_d${second}:  di %9.3f round(_b[d_m_FE_mean],0.001)
				local se1_rf_`y'_d${second}: di %9.3f round(_se[d_m_FE_mean],0.001)
				local N_rf_`y'_d${second}=e(N)
			}		
		}
		
			
		*** Exclude (m1, p1), (m1, p2), (m1, p3), (m1, p4) , (m1, p5), (m1, p6)
		if "`indicator'"=="ex_m1_p1" | "`indicator'"=="ex_m1_p2" | "`indicator'"=="ex_m1_p3"  | "`indicator'"=="ex_m1_p4" | "`indicator'"=="ex_m1_p5" | "`indicator'"=="ex_m1_p6" {
			di "${first} ${second}"
		
			* Generate First Differences
			xtset
			foreach y of varlist lprod_sede3 lproduz_eq_sede lforza_eq ldisp lwage_1_30 abs_rate aqual_pp aformaz astraord lY_full aassunzione_p_c afires_p_c acambio_sede_in_p_c acambio_sede_out_p_c lqual_pp lgiac_fin lpervenuto asep_young_c asep_pens_nc_p_c lprod_sede2 {
				gen fd_`y'= F${s}.`y'-L.`y' if event_time==0
			}
			
			* These variable names are too long, so I shorten them
			rename fd_acambio_sede_in_p_c fd_acamb_in_p_c
			rename fd_acambio_sede_out_p_c fd_acamb_out_p_c

	
			* Dep. variables
			foreach y in fd_lprod_sede3 fd_lY_full fd_lforza_eq fd_asep_pens_nc_p_c fd_aassunzione_p_c fd_afires_p_c fd_acamb_in_p_c fd_acamb_out_p_c fd_asep_young_c fd_abs_rate fd_aformaz fd_astraord fd_ldisp fd_lwage_1_30 fd_lqual_pp fd_lgiac_fin fd_lpervenuto fd_lprod_sede2 {

				reg  `y' d_m_FE_mean i.year_quarter i.geo2 i.exo_strict i.year_quarter#i.geo2 ///
					i.geo2#i.exo_strict i.prod0_quart##i.exo_strict ///
					if super_mis!=1 ///
					[aweight=${weights}], vce(cl cod_sede_giu2_num)
				parmest, saving("$tempfiles/Dp_Dm_`y'_${first}_${second}${b}.dta", replace)
				
				local b1_rf_`y'_d${second}:  di %9.3f round(_b[d_m_FE_mean],0.001)
				local se1_rf_`y'_d${second}: di %9.3f round(_se[d_m_FE_mean],0.001)
				local N_rf_`y'_d${second}=e(N)
			}
		}
	}
}	

*********************************************************************************

* Tables for the non-bootstrapped SE
if  ${bootstrap} ==0 {
	*** ESTIMATES FOR FIGURE 3 
	tempfile t
	writeln `t' "\begin{table}[htbp]\centering \caption{Estimated Effects of Changes in Managerial Talent} \begin{tabular}{l*{3}{c}} \hline \hline &	(1) & (2) & (3)\\"
	writeln `t' "\multicolumn{1}{l}{k}  &\multicolumn{1}{c}{Ln(Productivity)} &\multicolumn{1}{c}{Ln(Output)}  & \multicolumn{1}{c}{Ln(FTE)} \\"
	writeln `t' "\hline\hline"

	writeln `t' " -4 & `b1_rf_fd_lprod_sede3_dm4' & `b1_rf_fd_lY_full_dm4' & `b1_rf_fd_lforza_eq_dm4'   \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dm4') & (`se1_rf_fd_lY_full_dm4') & (`se1_rf_fd_lforza_eq_dm4') \\"

	writeln `t' " -3 & `b1_rf_fd_lprod_sede3_dm3' & `b1_rf_fd_lY_full_dm3' & `b1_rf_fd_lforza_eq_dm3' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dm3') & (`se1_rf_fd_lY_full_dm3') & (`se1_rf_fd_lforza_eq_dm3') \\"

	writeln `t' " -2 & `b1_rf_fd_lprod_sede3_dm2' & `b1_rf_fd_lY_full_dm2' & `b1_rf_fd_lforza_eq_dm2' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dm2') & (`se1_rf_fd_lY_full_dm2') & (`se1_rf_fd_lforza_eq_dm2') \\"

	writeln `t' " 0 & `b1_rf_fd_lprod_sede3_dp0' & `b1_rf_fd_lY_full_dp0' & `b1_rf_fd_lforza_eq_dp0' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp0') & (`se1_rf_fd_lY_full_dp0') & (`se1_rf_fd_lforza_eq_dp0') \\"

	writeln `t' " 1 & `b1_rf_fd_lprod_sede3_dp1' & `b1_rf_fd_lY_full_dp1' & `b1_rf_fd_lforza_eq_dp1' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp1') & (`se1_rf_fd_lY_full_dp1') & (`se1_rf_fd_lforza_eq_dp1') \\"

	writeln `t' " 2 & `b1_rf_fd_lprod_sede3_dp2' & `b1_rf_fd_lY_full_dp2' & `b1_rf_fd_lforza_eq_dp2' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp2') & (`se1_rf_fd_lY_full_dp2') & (`se1_rf_fd_lforza_eq_dp2') \\"

	writeln `t' " 3 & `b1_rf_fd_lprod_sede3_dp3' & `b1_rf_fd_lY_full_dp3' & `b1_rf_fd_lforza_eq_dp3' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp3') & (`se1_rf_fd_lY_full_dp3') & (`se1_rf_fd_lforza_eq_dp3') \\"

	writeln `t' " 4 & `b1_rf_fd_lprod_sede3_dp4' & `b1_rf_fd_lY_full_dp4' & `b1_rf_fd_lforza_eq_dp4' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp4') & (`se1_rf_fd_lY_full_dp4') & (`se1_rf_fd_lforza_eq_dp4') \\"

	writeln `t' " 5 & `b1_rf_fd_lprod_sede3_dp5' & `b1_rf_fd_lY_full_dp5' & `b1_rf_fd_lforza_eq_dp5' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp5') & (`se1_rf_fd_lY_full_dp5') & (`se1_rf_fd_lforza_eq_dp5') \\"

	writeln `t' " 6 & `b1_rf_fd_lprod_sede3_dp6' & `b1_rf_fd_lY_full_dp6' & `b1_rf_fd_lforza_eq_dp6' \\"
	writeln `t' "  & (`se1_rf_fd_lprod_sede3_dp6') & (`se1_rf_fd_lY_full_dp6') & (`se1_rf_fd_lforza_eq_dp6') \\"

	writeln `t' "\midrule"
	writeln `t' " N & `N_rf_fd_lprod_sede3_d${second}' & `N_rf_fd_lY_full_d${second}' & `N_rf_fd_lforza_eq_d${second}' \\"

	writeln `t' " Time FE & Yes & Yes & Yes \\"

	writeln `t' "\hline\hline"	
	writeln `t' "\multicolumn{4}{l}{\footnotesize SE are clustered at the office level.}\\"	
	writeln `t' "\multicolumn{4}{l}{\footnotesize SE in parenthesis.}\\"	
	writeln `t' "\end{tabular}"
	writeln `t' "\end{table}"

	! cat `t' > "$tables/Estimates_Figure3.tex"


	*** TABLE 8
	tempfile t
	writeln `t' "\begin{table}[htbp]\centering \caption{Estimated Effects of Changes in Managerial Talent on Office Composition} \begin{tabular}{l*{6}{c}} \hline \hline & (1) & (2) & (3) & (4) & (5) & (6) \\ "
	writeln `t' " \multicolumn{1}{l}{k}  &\multicolumn{1}{c}{A(Retirement)} &\multicolumn{1}{c}{A(Separations)} &\multicolumn{1}{c}{A(Hires)}  & \multicolumn{1}{c}{A(Fires)} & \multicolumn{1}{c}{A(Inbound T)} & \multicolumn{1}{c}{A(Outbound T)} \\"
	writeln `t' "\hline\hline"

	writeln `t' " -4 & `b1_rf_fd_asep_pens_nc_p_c_dm4' & `b1_rf_fd_asep_young_c_dm4' & `b1_rf_fd_aassunzione_p_c_dm4' & `b1_rf_fd_afires_p_c_dm4' & `b1_rf_fd_acamb_in_p_c_dm4' & `b1_rf_fd_acamb_out_p_c_dm4' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dm4') & (`se1_rf_fd_asep_young_c_dm4') & (`se1_rf_fd_aassunzione_p_c_dm4') & (`se1_rf_fd_afires_p_c_dm4') & (`se1_rf_fd_acamb_in_p_c_dm4') & (`se1_rf_fd_acamb_out_p_c_dm4') \\"

	writeln `t' " -3 & `b1_rf_fd_asep_pens_nc_p_c_dm3' & `b1_rf_fd_asep_young_c_dm3'   & `b1_rf_fd_aassunzione_p_c_dm3' & `b1_rf_fd_afires_p_c_dm3' & `b1_rf_fd_acamb_in_p_c_dm3' & `b1_rf_fd_acamb_out_p_c_dm3' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dm3') & (`se1_rf_fd_asep_young_c_dm3') & (`se1_rf_fd_aassunzione_p_c_dm3') & (`se1_rf_fd_afires_p_c_dm3') & (`se1_rf_fd_acamb_in_p_c_dm3') & (`se1_rf_fd_acamb_out_p_c_dm3') \\"

	writeln `t' " -2 & `b1_rf_fd_asep_pens_nc_p_c_dm2' & `b1_rf_fd_asep_young_c_dm2' & `b1_rf_fd_aassunzione_p_c_dm2' & `b1_rf_fd_afires_p_c_dm2' & `b1_rf_fd_acamb_in_p_c_dm2' & `b1_rf_fd_acamb_out_p_c_dm2' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dm2') & (`se1_rf_fd_asep_young_c_dm2') & (`se1_rf_fd_aassunzione_p_c_dm2') & (`se1_rf_fd_afires_p_c_dm2') & (`se1_rf_fd_acamb_in_p_c_dm2') & (`se1_rf_fd_acamb_out_p_c_dm2') \\"

	writeln `t' " 0 & `b1_rf_fd_asep_pens_nc_p_c_dp0' & `b1_rf_fd_asep_young_c_dp0' & `b1_rf_fd_aassunzione_p_c_dp0' & `b1_rf_fd_afires_p_c_dp0' & `b1_rf_fd_acamb_in_p_c_dp0' & `b1_rf_fd_acamb_out_p_c_dp0' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp0') & (`se1_rf_fd_asep_young_c_dp0') & (`se1_rf_fd_aassunzione_p_c_dp0') & (`se1_rf_fd_afires_p_c_dp0') & (`se1_rf_fd_acamb_in_p_c_dp0') & (`se1_rf_fd_acamb_out_p_c_dp0') \\"

	writeln `t' " 1 & `b1_rf_fd_asep_pens_nc_p_c_dp1' & `b1_rf_fd_asep_young_c_dp1' & `b1_rf_fd_aassunzione_p_c_dp1' & `b1_rf_fd_afires_p_c_dp1' & `b1_rf_fd_acamb_in_p_c_dp1' & `b1_rf_fd_acamb_out_p_c_dp1' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp1') & (`se1_rf_fd_asep_young_c_dp1') & (`se1_rf_fd_aassunzione_p_c_dp1') & (`se1_rf_fd_afires_p_c_dp1') & (`se1_rf_fd_acamb_in_p_c_dp1') & (`se1_rf_fd_acamb_out_p_c_dp1') \\"

	writeln `t' " 2 & `b1_rf_fd_asep_pens_nc_p_c_dp2' & `b1_rf_fd_asep_young_c_dp2' & `b1_rf_fd_aassunzione_p_c_dp2' & `b1_rf_fd_afires_p_c_dp2' & `b1_rf_fd_acamb_in_p_c_dp2' & `b1_rf_fd_acamb_out_p_c_dp2' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp2') & (`se1_rf_fd_asep_young_c_dp2') & (`se1_rf_fd_aassunzione_p_c_dp2') & (`se1_rf_fd_afires_p_c_dp2') & (`se1_rf_fd_acamb_in_p_c_dp2') & (`se1_rf_fd_acamb_out_p_c_dp2')  \\"

	writeln `t' " 3 & `b1_rf_fd_asep_pens_nc_p_c_dp3' & `b1_rf_fd_asep_young_c_dp3' & `b1_rf_fd_aassunzione_p_c_dp3' & `b1_rf_fd_afires_p_c_dp3' & `b1_rf_fd_acamb_in_p_c_dp3' & `b1_rf_fd_acamb_out_p_c_dp3' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp3') & (`se1_rf_fd_asep_young_c_dp3') & (`se1_rf_fd_aassunzione_p_c_dp3') & (`se1_rf_fd_afires_p_c_dp3') & (`se1_rf_fd_acamb_in_p_c_dp3') & (`se1_rf_fd_acamb_out_p_c_dp3') \\"

	writeln `t' " 4 & `b1_rf_fd_asep_pens_nc_p_c_dp4' & `b1_rf_fd_asep_young_c_dp4' & `b1_rf_fd_aassunzione_p_c_dp4' & `b1_rf_fd_afires_p_c_dp4' & `b1_rf_fd_acamb_in_p_c_dp4' & `b1_rf_fd_acamb_out_p_c_dp4' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp4') & (`se1_rf_fd_asep_young_c_dp4') & (`se1_rf_fd_aassunzione_p_c_dp4') & (`se1_rf_fd_afires_p_c_dp4') & (`se1_rf_fd_acamb_in_p_c_dp4') & (`se1_rf_fd_acamb_out_p_c_dp4') \\"

	writeln `t' " 5 & `b1_rf_fd_asep_pens_nc_p_c_dp5' & `b1_rf_fd_asep_young_c_dp5' & `b1_rf_fd_aassunzione_p_c_dp5' & `b1_rf_fd_afires_p_c_dp5' & `b1_rf_fd_acamb_in_p_c_dp5' & `b1_rf_fd_acamb_out_p_c_dp5' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp5') & (`se1_rf_fd_asep_young_c_dp5') & (`se1_rf_fd_aassunzione_p_c_dp5') & (`se1_rf_fd_afires_p_c_dp5') & (`se1_rf_fd_acamb_in_p_c_dp5') & (`se1_rf_fd_acamb_out_p_c_dp5') \\"

	writeln `t' " 6 & `b1_rf_fd_asep_pens_nc_p_c_dp6' & `b1_rf_fd_asep_young_c_dp6' & `b1_rf_fd_aassunzione_p_c_dp6' & `b1_rf_fd_afires_p_c_dp6' & `b1_rf_fd_acamb_in_p_c_dp6' & `b1_rf_fd_acamb_out_p_c_dp6' \\"
	writeln `t' "  & (`se1_rf_fd_asep_pens_nc_p_c_dp6') & (`se1_rf_fd_asep_young_c_dp6') & (`se1_rf_fd_aassunzione_p_c_dp6') & (`se1_rf_fd_afires_p_c_dp6') & (`se1_rf_fd_acamb_in_p_c_dp6') & (`se1_rf_fd_acamb_out_p_c_dp6') \\"

	writeln `t' "\midrule"
	writeln `t' " N & `N_rf_fd_asep_pens_nc_p_c_d${second}' & `N_rf_fd_asep_young_c_d${second}' & `N_rf_fd_aassunzione_p_c_d${second}' & `N_rf_fd_afires_p_c_d${second}' & `N_rf_fd_acamb_in_p_c_d${second}' & `N_rf_fd_acamb_out_p_c_d${second}' \\"

	writeln `t' " Time FE & Yes & Yes & Yes & Yes & Yes & Yes  \\"

	writeln `t' "\hline\hline"	
	writeln `t' "\multicolumn{6}{l}{\footnotesize SE are clustered at the office level.}\\"	
	writeln `t' "\multicolumn{6}{l}{\footnotesize SE in parenthesis.}\\"	
	writeln `t' "\end{tabular}"
	writeln `t' "\end{table}"

	! cat `t' > "$tables/Table8.tex"

	*** TABLE 9
	tempfile t
	writeln `t' "\begin{table}[htbp]\centering \caption{Estimated Effects of Changes in Managerial Talent on Quality, Backlog, and Demand} \begin{tabular}{l*{3}{c}} \hline \hline & (1) & (2) & (3) \\ "
	writeln `t' " \multicolumn{1}{l}{k}  &\multicolumn{1}{c}{Ln(Quality)} &\multicolumn{1}{c}{Ln(Backlog)}  & \multicolumn{1}{c}{Ln(Demand)} \\"
	writeln `t' "\hline\hline"

	writeln `t' " -4 & `b1_rf_fd_lqual_pp_dm4' & `b1_rf_fd_lgiac_fin_dm4' & `b1_rf_fd_lpervenuto_dm4'   \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dm4') & (`se1_rf_fd_lgiac_fin_dm4') & (`se1_rf_fd_lpervenuto_dm4') \\"

	writeln `t' " -3 & `b1_rf_fd_lqual_pp_dm3' & `b1_rf_fd_lgiac_fin_dm3' & `b1_rf_fd_lpervenuto_dm3' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dm3') & (`se1_rf_fd_lgiac_fin_dm3') & (`se1_rf_fd_lpervenuto_dm3') \\"

	writeln `t' " -2 & `b1_rf_fd_lqual_pp_dm2' & `b1_rf_fd_lgiac_fin_dm2' & `b1_rf_fd_lpervenuto_dm2' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dm2') & (`se1_rf_fd_lgiac_fin_dm2') & (`se1_rf_fd_lpervenuto_dm2') \\"

	writeln `t' " 0 & `b1_rf_fd_lqual_pp_dp0' & `b1_rf_fd_lgiac_fin_dp0' & `b1_rf_fd_lpervenuto_dp0' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp0') & (`se1_rf_fd_lgiac_fin_dp0') & (`se1_rf_fd_lpervenuto_dp0') \\"

	writeln `t' " 1 & `b1_rf_fd_lqual_pp_dp1' & `b1_rf_fd_lgiac_fin_dp1' & `b1_rf_fd_lpervenuto_dp1' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp1') & (`se1_rf_fd_lgiac_fin_dp1') & (`se1_rf_fd_lpervenuto_dp1') \\"

	writeln `t' " 2 & `b1_rf_fd_lqual_pp_dp2' & `b1_rf_fd_lgiac_fin_dp2' & `b1_rf_fd_lpervenuto_dp2' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp2') & (`se1_rf_fd_lgiac_fin_dp2') & (`se1_rf_fd_lpervenuto_dp2') \\"

	writeln `t' " 3 & `b1_rf_fd_lqual_pp_dp3' & `b1_rf_fd_lgiac_fin_dp3' & `b1_rf_fd_lpervenuto_dp3' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp3') & (`se1_rf_fd_lgiac_fin_dp3') & (`se1_rf_fd_lpervenuto_dp3') \\"

	writeln `t' " 4 & `b1_rf_fd_lqual_pp_dp4' & `b1_rf_fd_lgiac_fin_dp4' & `b1_rf_fd_lpervenuto_dp4' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp4') & (`se1_rf_fd_lgiac_fin_dp4') & (`se1_rf_fd_lpervenuto_dp4') \\"

	writeln `t' " 5 & `b1_rf_fd_lqual_pp_dp5' & `b1_rf_fd_lgiac_fin_dp5' & `b1_rf_fd_lpervenuto_dp5' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp5') & (`se1_rf_fd_lgiac_fin_dp5') & (`se1_rf_fd_lpervenuto_dp5') \\"

	writeln `t' " 6 & `b1_rf_fd_lqual_pp_dp6' & `b1_rf_fd_lgiac_fin_dp6' & `b1_rf_fd_lpervenuto_dp6' \\"
	writeln `t' "  & (`se1_rf_fd_lqual_pp_dp6') & (`se1_rf_fd_lgiac_fin_dp6') & (`se1_rf_fd_lpervenuto_dp6') \\"

	writeln `t' "\midrule"
	writeln `t' " N & `N_rf_fd_lqual_pp_d${second}' & `N_rf_fd_lgiac_fin_d${second}' & `N_rf_fd_lpervenuto_d${second}' \\"

	writeln `t' " Time FE & Yes & Yes & Yes \\"

	writeln `t' "\hline\hline"	
	writeln `t' "\multicolumn{4}{l}{\footnotesize SE are clustered at the office level.}\\"	
	writeln `t' "\multicolumn{4}{l}{\footnotesize SE in parenthesis.}\\"	
	writeln `t' "\end{tabular}"
	writeln `t' "\end{table}"

	! cat `t' > "$tables/Table9.tex"


	*** APPENDIX TABLE G1
	tempfile t
	writeln `t' "\begin{table}[htbp]\centering \caption{Estimated Effects of Changes in Managerial Talent on Time Allocation} \begin{tabular}{l*{5}{c}} \hline \hline & (1) & (2) & (3) & (4) & (5) \\ "
	writeln `t' " \multicolumn{1}{l}{k}  &\multicolumn{1}{c}{Abs. Rate} &\multicolumn{1}{c}{A(Training)}  & \multicolumn{1}{c}{A(Overtime)} & \multicolumn{1}{c}{Ln(Hours)} & \multicolumn{1}{c}{Ln(Wage Bill 30\%)} \\"
	writeln `t' "\hline\hline"

	writeln `t' " -4 & `b1_rf_fd_abs_rate_dm4' & `b1_rf_fd_aformaz_dm4' & `b1_rf_fd_astraord_dm4' & `b1_rf_fd_ldisp_dm4' & `b1_rf_fd_lwage_1_30_dm4' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dm4') & (`se1_rf_fd_aformaz_dm4') & (`se1_rf_fd_astraord_dm4') & (`se1_rf_fd_ldisp_dm4') & (`se1_rf_fd_lwage_1_30_dm4') \\"

	writeln `t' " -3 & `b1_rf_fd_abs_rate_dm3' & `b1_rf_fd_aformaz_dm3' & `b1_rf_fd_astraord_dm3' & `b1_rf_fd_ldisp_dm3' & `b1_rf_fd_lwage_1_30_dm3' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dm3') & (`se1_rf_fd_aformaz_dm3') & (`se1_rf_fd_astraord_dm3') & (`se1_rf_fd_ldisp_dm3') & (`se1_rf_fd_lwage_1_30_dm3') \\"

	writeln `t' " -2 & `b1_rf_fd_abs_rate_dm2' & `b1_rf_fd_aformaz_dm2' & `b1_rf_fd_astraord_dm2' & `b1_rf_fd_ldisp_dm2' & `b1_rf_fd_lwage_1_30_dm2' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dm2') & (`se1_rf_fd_aformaz_dm2') & (`se1_rf_fd_astraord_dm2') & (`se1_rf_fd_ldisp_dm2') & (`se1_rf_fd_lwage_1_30_dm2') \\"

	writeln `t' " 0 & `b1_rf_fd_abs_rate_dp0' & `b1_rf_fd_aformaz_dp0' & `b1_rf_fd_astraord_dp0' & `b1_rf_fd_ldisp_dp0' & `b1_rf_fd_lwage_1_30_dp0' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp0') & (`se1_rf_fd_aformaz_dp0') & (`se1_rf_fd_astraord_dp0') & (`se1_rf_fd_ldisp_dp0') & (`se1_rf_fd_lwage_1_30_dp0') \\"

	writeln `t' " 1 & `b1_rf_fd_abs_rate_dp1' & `b1_rf_fd_aformaz_dp1' & `b1_rf_fd_astraord_dp1' & `b1_rf_fd_ldisp_dp1' & `b1_rf_fd_lwage_1_30_dp1' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp1') & (`se1_rf_fd_aformaz_dp1') & (`se1_rf_fd_astraord_dp1') & (`se1_rf_fd_ldisp_dp1') & (`se1_rf_fd_lwage_1_30_dp1') \\"

	writeln `t' " 2 & `b1_rf_fd_abs_rate_dp2' & `b1_rf_fd_aformaz_dp2' & `b1_rf_fd_astraord_dp2' & `b1_rf_fd_ldisp_dp2' & `b1_rf_fd_lwage_1_30_dp2' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp2') & (`se1_rf_fd_aformaz_dp2') & (`se1_rf_fd_astraord_dp2') & (`se1_rf_fd_ldisp_dp2') & (`se1_rf_fd_lwage_1_30_dp2')  \\"

	writeln `t' " 3 & `b1_rf_fd_abs_rate_dp3' & `b1_rf_fd_aformaz_dp3' & `b1_rf_fd_astraord_dp3' & `b1_rf_fd_ldisp_dp3' & `b1_rf_fd_lwage_1_30_dp3' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp3') & (`se1_rf_fd_aformaz_dp3') & (`se1_rf_fd_astraord_dp3') & (`se1_rf_fd_ldisp_dp3') & (`se1_rf_fd_lwage_1_30_dp3') \\"

	writeln `t' " 4 & `b1_rf_fd_abs_rate_dp4' & `b1_rf_fd_aformaz_dp4' & `b1_rf_fd_astraord_dp4' & `b1_rf_fd_ldisp_dp4' & `b1_rf_fd_lwage_1_30_dp4' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp4') & (`se1_rf_fd_aformaz_dp4') & (`se1_rf_fd_astraord_dp4') & (`se1_rf_fd_ldisp_dp4') & (`se1_rf_fd_lwage_1_30_dp4') \\"

	writeln `t' " 5 & `b1_rf_fd_abs_rate_dp5' & `b1_rf_fd_aformaz_dp5' & `b1_rf_fd_astraord_dp5' & `b1_rf_fd_ldisp_dp5' & `b1_rf_fd_lwage_1_30_dp5' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp5') & (`se1_rf_fd_aformaz_dp5') & (`se1_rf_fd_astraord_dp5') & (`se1_rf_fd_ldisp_dp5') & (`se1_rf_fd_lwage_1_30_dp5') \\"

	writeln `t' " 6 & `b1_rf_fd_abs_rate_dp6' & `b1_rf_fd_aformaz_dp6' & `b1_rf_fd_astraord_dp6' & `b1_rf_fd_ldisp_dp6' & `b1_rf_fd_lwage_1_30_dp6' \\"
	writeln `t' "  & (`se1_rf_fd_abs_rate_dp6') & (`se1_rf_fd_aformaz_dp6') & (`se1_rf_fd_astraord_dp6') & (`se1_rf_fd_ldisp_dp6') & (`se1_rf_fd_lwage_1_30_dp6') \\"

	writeln `t' "\midrule"
	writeln `t' " N & `N_rf_fd_abs_rate_d${second}' & `N_rf_fd_aformaz_d${second}' & `N_rf_fd_astraord_d${second}' & `N_rf_fd_ldisp_d${second}' & `N_rf_fd_lwage_1_30_d${second}' \\"

	writeln `t' " Time FE & Yes & Yes & Yes & Yes & Yes  \\"

	writeln `t' "\hline\hline"	
	writeln `t' "\multicolumn{6}{l}{\footnotesize SE are clustered at the office level.}\\"	
	writeln `t' "\multicolumn{6}{l}{\footnotesize SE in parenthesis.}\\"	
	writeln `t' "\end{tabular}"
	writeln `t' "\end{table}"

	! cat `t' > "$tables/TableG1.tex"
}

*********************************************************************************

* Bootstrapped SE
if ${bootstrap} ==1 {

	foreach y in fd_lprod_sede3 fd_lY_full fd_lforza_eq fd_asep_pens_nc_p_c fd_aassunzione_p_c fd_afires_p_c fd_acamb_in_p_c fd_acamb_out_p_c fd_asep_young_c fd_abs_rate fd_aformaz fd_astraord fd_ldisp fd_lwage_1_30 fd_lqual_pp fd_lgiac_fin fd_lpervenuto fd_lprod_sede2 {
		
		di "`y'"
		clear

		gen event_time=.
		gen iteration=.
		
		forvalues i = 1(1)$iterations {

			foreach num of numlist 2/${lower_bound_abs} {
				append using "$tempfiles/Dp_Dm_`y'_m1_m`num'_boot_`i'.dta"
				replace event_time=-`num' if event_time==.

			}
			foreach num of numlist 0/${upper_bound} {
				append using "$tempfiles/Dp_Dm_`y'_m1_p`num'_boot_`i'.dta"
				replace event_time=`num' if event_time==.

			}
			
			keep if parm=="d_m_FE_mean"
			replace iteration=`i' if iteration==.
		
		}
		
		bys event_time: egen sd_boot=sd(estimate)
		keep event_time sd_boot
		duplicates drop
		save "$tempfiles/`y'_se_boot.dta", replace
	}	
}	
	
	
	
